Changelog
---------

1.0.1 (05.11.2025)
~~~~~~~~~~~~~~~~~~~

- Fixes link to this changelog in the project urls
- Cleans up implementation a little

1.0.0 (05.11.2025)
~~~~~~~~~~~~~~~~~~~

- Initial Release
